==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/StateEventMatrixEntrySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.CantHappenSet;
import io.ciera.tool.sql.ooaofooa.statemachine.EventIgnoredSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntry;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.CantHappenSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.EventIgnoredSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NewStateTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SEMEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;

import java.util.Arrays;
import java.util.List;


public class StateEventMatrixEntrySetImpl extends InstanceSet<StateEventMatrixEntrySet,StateEventMatrixEntry> implements StateEventMatrixEntrySet {

    // attributes
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSMstt_ID( ref_SMstt_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public StateMachineStateSet R503_is_received_by_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) statemachinestateset.add( stateeventmatrixentry.R503_is_received_by_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public SEMEventSet R503_receives_SEMEvent() throws XtumlException {
        SEMEventSet semeventset = new SEMEventSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) semeventset.add( stateeventmatrixentry.R503_receives_SEMEvent() );
        return semeventset;
    }
    @Override
    public CantHappenSet R504_is_a_CantHappen() throws XtumlException {
        CantHappenSet canthappenset = new CantHappenSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) canthappenset.add( stateeventmatrixentry.R504_is_a_CantHappen() );
        return canthappenset;
    }
    @Override
    public EventIgnoredSet R504_is_a_EventIgnored() throws XtumlException {
        EventIgnoredSet eventignoredset = new EventIgnoredSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) eventignoredset.add( stateeventmatrixentry.R504_is_a_EventIgnored() );
        return eventignoredset;
    }
    @Override
    public NewStateTransitionSet R504_is_a_NewStateTransition() throws XtumlException {
        NewStateTransitionSet newstatetransitionset = new NewStateTransitionSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) newstatetransitionset.add( stateeventmatrixentry.R504_is_a_NewStateTransition() );
        return newstatetransitionset;
    }


    @Override
    public StateEventMatrixEntry nullElement() {
        return StateEventMatrixEntryImpl.EMPTY_STATEEVENTMATRIXENTRY;
    }

    @Override
    public StateEventMatrixEntrySet emptySet() {
      return new StateEventMatrixEntrySetImpl();
    }

    @Override
    public StateEventMatrixEntrySet value() {
        return this;
    }

    @Override
    public List<StateEventMatrixEntry> elements() {
        return Arrays.asList(toArray(new StateEventMatrixEntry[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/StateEventMatrixEntrySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.CantHappenSet;
import io.ciera.tool.sql.ooaofooa.statemachine.EventIgnoredSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntry;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineStateSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.CantHappenSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.EventIgnoredSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NewStateTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SEMEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineStateSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class StateEventMatrixEntrySetImpl extends InstanceSet<StateEventMatrixEntrySet,StateEventMatrixEntry> implements StateEventMatrixEntrySet {

    public StateEventMatrixEntrySetImpl() {
    }

    public StateEventMatrixEntrySetImpl(Comparator<? super StateEventMatrixEntry> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSMstt_ID( ref_SMstt_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) stateeventmatrixentry.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public StateMachineStateSet R503_is_received_by_StateMachineState() throws XtumlException {
        StateMachineStateSet statemachinestateset = new StateMachineStateSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) statemachinestateset.add( stateeventmatrixentry.R503_is_received_by_StateMachineState() );
        return statemachinestateset;
    }
    @Override
    public SEMEventSet R503_receives_SEMEvent() throws XtumlException {
        SEMEventSet semeventset = new SEMEventSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) semeventset.add( stateeventmatrixentry.R503_receives_SEMEvent() );
        return semeventset;
    }
    @Override
    public CantHappenSet R504_is_a_CantHappen() throws XtumlException {
        CantHappenSet canthappenset = new CantHappenSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) canthappenset.add( stateeventmatrixentry.R504_is_a_CantHappen() );
        return canthappenset;
    }
    @Override
    public EventIgnoredSet R504_is_a_EventIgnored() throws XtumlException {
        EventIgnoredSet eventignoredset = new EventIgnoredSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) eventignoredset.add( stateeventmatrixentry.R504_is_a_EventIgnored() );
        return eventignoredset;
    }
    @Override
    public NewStateTransitionSet R504_is_a_NewStateTransition() throws XtumlException {
        NewStateTransitionSet newstatetransitionset = new NewStateTransitionSetImpl();
        for ( StateEventMatrixEntry stateeventmatrixentry : this ) newstatetransitionset.add( stateeventmatrixentry.R504_is_a_NewStateTransition() );
        return newstatetransitionset;
    }


    @Override
    public StateEventMatrixEntry nullElement() {
        return StateEventMatrixEntryImpl.EMPTY_STATEEVENTMATRIXENTRY;
    }

    @Override
    public StateEventMatrixEntrySet emptySet() {
      return new StateEventMatrixEntrySetImpl();
    }

    @Override
    public StateEventMatrixEntrySet emptySet(Comparator<? super StateEventMatrixEntry> comp) {
      return new StateEventMatrixEntrySetImpl(comp);
    }

    @Override
    public StateEventMatrixEntrySet value() {
        return this;
    }

    @Override
    public List<StateEventMatrixEntry> elements() {
        return Arrays.asList(toArray(new StateEventMatrixEntry[0]));
    }

}
